docstripy.numpy
===============

docstripy.numpy.build\_doc
--------------------------

.. automodule:: docstripy.numpy.build_doc
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.numpy.parse\_doc
--------------------------

.. automodule:: docstripy.numpy.parse_doc
   :members:
   :undoc-members:
   :show-inheritance:
